@@ -16,7 +16,7 @@ class Exception(Object):
         self.parent = runtime.find("Object")
 
     def __repr__(self):
-        return "{0:s}({0;s})".format(self.type, self.value or "")
+        return "{0:s}({1:s})".format(self.type, self.value or "")
 
     @method("try")
     def tryEval(self, receiver, context, m, code):
