@@ -11,13 +11,17 @@ class AttributeError(Error):
     """AttributeError"""
 
 
-class TypeError(Error):
-    """TypeError"""
-
-
 class ImportError(Error):
     """ImportError"""
 
 
+class IndexError(Error):
+    """IndexError"""
+
+
+class TypeError(Error):
+    """TypeError"""
+
+
 class UserError(Error):
     """UserError"""
