@@ -1,9 +1,6 @@
-from copy import copy
-
-
 from mio import runtime
+from mio.utils import method
 from mio.object import Object
-from mio.utils import method, Null
 
 
 class Dict(Object):
@@ -24,13 +21,11 @@ class Dict(Object):
         return "Dict"
 
     @method()
-    def init(self, receiver, context, m, *args):
-        ctx = runtime.find("Object").clone()
-        if len(args) == 1 and args[0].eval(ctx).type == "Dict":
-            receiver.value = args[0].eval(ctx).value
+    def init(self, receiver, context, m, iterable=None):
+        if isinstance(iterable, Dict):
+            receiver.value = iterable.value.copy()
         else:
-            [arg.eval(ctx) for arg in args]
-            receiver.value = ctx.attrs
+            receiver.value = dict(iterable) if iterable is not None else dict()
         return receiver
 
     # General Operations
@@ -49,20 +44,20 @@ class Dict(Object):
         del receiver.value[key.eval(context)]
         return receiver
 
-    @method()
+    @method(property=True)
     def keys(self, receiver, context, m):
         return runtime.find("List").clone(receiver.value.keys())
 
-    @method()
+    @method(property=True)
     def items(self, receiver, context, m):
         List = runtime.find("List")
         items = [List.clone([k, v]) for k, v in receiver.value.items()]
         return runtime.find("List").clone(items)
 
-    @method()
+    @method(property=True)
     def values(self, receiver, context, m):
         return runtime.find("List").clone(receiver.value.values())
 
-    @method()
+    @method(property=True)
     def len(self, receiver, context, m):
         return runtime.find("Number").clone(len(receiver.value))
