@@ -1,5 +1,5 @@
 from warnings import warn
-from inspect import getargspec, ismethod
+from inspect import getargspec, isfunction, ismethod
 
 
 from mio import runtime
@@ -17,6 +17,10 @@ def format_method(f):
     return "%s(%s)" % (name, args)
 
 
+def format_function(f):
+    return getattr(f, "__doc__", "") or format_method(f)
+
+
 def format_object(o):
     def format_key(k):
         return str(k).ljust(15)
@@ -24,18 +28,21 @@ def format_object(o):
     def format_value(v):
         if ismethod(v):
             return format_method(v)
+        elif isfunction(v):
+            return format_function(v)
         else:
-            return str(runtime.state.eval("repr()", receiver=v))
+            return str(runtime.state.eval("__repr__()", receiver=v))
 
     attrs = "\n".join(["  {0:s} = {1:s}".format(format_key(k), format_value(v)) for k, v in sorted(o.attrs.items())])
 
     return "{0:s}:\n{1:s}".format(repr(o), attrs)
 
 
-def method(name=None):
+def method(name=None, property=False):
     def wrapper(f):
         f.name = name if name is not None else f.__name__
         f.method = True
+        f.property = property
 
         argspec = getargspec(f)
         args = argspec.args
